@@ -56,7 +56,9 @@ class ApiGatewayHandler(EventsHandler, ABC):
 
         try:
 
+            self.preprocess_function()
             response_body = self.perform_action()
+            self.postprocess_function()
 
             response = ApiGatewayResponse(
                 status_code=self.success_code, body=response_body
@@ -75,6 +77,12 @@ class ApiGatewayHandler(EventsHandler, ABC):
 
         return response
 
+    def preprocess_function(self):
+        pass
+
+    def postprocess_function(self):
+        pass
+
     def process_error(self, exception):
         for handler in self.error_handlers:
             if handler.is_my_exception(exception):
@@ -83,14 +91,11 @@ class ApiGatewayHandler(EventsHandler, ABC):
                     body=handler.generate_error_message(exception),
                 )
 
-        logger.exception(exception)
-        return ApiGatewayResponse(
-            status_code=500, body={"message": "Internal Server Error"}
-        )
+        self.process_unhandled_error(error=exception)
 
     def process_unhandled_error(self, error):
         logger.exception(error)
-        return ApiGatewayResponse(
+        self.response = ApiGatewayResponse(
             status_code=500, body={"message": "Internal Server Error"}
         )
 
